@@ -6,7 +6,6 @@
 # Description:
 #	This is a collection of frunctions which support the following tasks:
 #    3 Absolute Moment Statistics
-#    4 Garch Ox Interface
 #    5 Missing Data Manipulations
 #    6 OLS Functions
 #    7 Moving Averages
@@ -88,252 +87,6 @@ function(n, density, ...)
 }
 
 
-################################################################################
-# 4 GARCH OX INTERFACE
-
-
-################################################################################
-# FUNCTION:            DESCRIPTION:
-#  garchOxFit           Fits parameters of a garch model           
-#  print.garchOx        S3 Print Method
-#  plot.garchOx         S3 Plot Method
-################################################################################
-
-
-garchOxFit = 
-function(formula.mean = ~ arma(0, 0), formula.var = ~ garch(1, 1), 
-series = x, cond.dist = c("gaussian", "t", "ged", "skewed-t"), 
-include.mean = TRUE, truncation = 100, trace = TRUE)
-{   # A function implemented by Diethelm Wuertz
-    
-    # Description:
-    #   Fits a time series by a ARMA-GARCH model interfacing Ox.
-    
-    # Arguments:
-    #   formula.mean -
-    #
-    #   formula.var - 
-    #
-    #   series -
-    #
-    #   cond.dist - a character string describing the distribution of 
-    #       innovations. By default the optimization is based on gaussian 
-    #       log likelihood parameter optimization denoted by "gaussian". 
-    #       Alternatively, a Student "t", "ged", or "skewed-t" can be chosen.    
-    #   include mean -
-    #   
-    #   truncation -
-    #
-    #   trace - a logical. Trace optimizer output? 
-    #       By default TRUE.
-   
-    # Value:
-    #   returns a list of class fGARCH with at least 
-    #   the following components:
-    #
-    #   order- the order of the fitted model.
-    #   coef - estimated GARCH coefficients for the fitted model.
-    #   n.likeli - the negative log-likelihood function evaluated 
-    #       at the coefficient estimates (apart from some constant).
-    #   n.used - the number of observations of "x".
-    #   residuals - the series of residuals.
-    #   fitted.values - the bivariate series of conditional standard
-    #       deviation predictions for "x".
-    #   series - the name of the series "x".
-    #   frequency - the frequency of the series "x".
-    #   call - the call of the \code{garch} function.}
-    #   asy.se.coef - the asymptotic-theory standard errors of the
-    #       coefficient estimates.
-    
-    # FUNCTION:
-    
-    # Fit:
-    fit = list()
-    fit$x = series
-    
-    # Include Constants:
-    include.var = TRUE
-    fit$csts = c(include.mean, include.var) 
-    
-    # Select Distribution:
-    # 0 : Gaussian
-    # 1 : Student-t
-    # 2 : GED
-    # 3 : Skewed-Student-t
-    distris = 0:3
-    names(distris) = c("gaussian", "t", "ged", "skewed-t")
-    distri = distris[cond.dist[1]]
-    fit$cond.dist = cond.dist[1]
-    
-    # Determine ARMA Order:
-    if (missing(formula.mean)) {
-        # if missing use ARMA(0, 0) ...
-        fit$formula.mean = ~ arma(0, 0)
-        fit$arma.orders = c(0, 0) }
-    else {
-        # otherwise determine orders "u" and "v" ...
-        fit$arma.orders = as.numeric(strsplit(strsplit(strsplit(as.character(
-            formula.mean), "\\(")[[2]][2], "\\)")[[1]], ",")[[1]]) }    
-    
-    # ARFIMA wanted?
-    arfima = FALSE
-    fit$arfima = as.integer(arfima)
-    
-    # Determine GARCH Order:        
-    if (missing(formula.var)) {
-        # if missing use GARCH(1, 1) ...
-        fit$formula.var = ~ garch(1, 1)
-        fit$garch.orders = c(1, 1) }
-    else {
-        # otherwise determine orders "p" and "q" ...
-        fit$garch.orders = as.numeric(strsplit(strsplit(strsplit(as.character(
-            formula.var), "\\(")[[2]][2], "\\)")[[1]], ",")[[1]]) } 
-    
-    # ARCH-IN-MEAN?
-    arch.in.mean = 0
-    fit$arch.in.mean = arch.in.mean
-    
-    # Selected Model:
-    models = 1:11
-    names(models) = c("garch", "egarch", "gjr", "aparch", "igarch", 
-        "figarch.bbm", "figarch.chung", "fiegarch", "fiaparch.bbm", 
-        "fiaparch.chung", "hygarch")
-    selected = strsplit(as.character(formula.var), "\\(")[[2]][1]
-    fit$model = models[selected]    
-    
-    # Length of Time Series:
-    nt = length(series)
-    
-    # Temporary File:
-    ident = paste(selected, as.character(floor(runif(1)*10000)), sep="")
-                                            
-    # Write parameters to file - OxParameter.txt:
-    parameters = c(fit$csts, distri, fit$arma.orders, fit$arfima, 
-        fit$garch.orders, fit$model, fit$arch.in.mean, truncation, nt)  
-    write(x=parameters, file="OxParameter.txt") 
-    
-    # Write data to file - OxSeries:
-    write(x="X", file="OxSeries.csv", ncolumns=1)
-    write(x, file="OxSeries.csv", ncolumns=1, append=TRUE)                      
-    
-    # Calculate:    
-    fit$ox = system(OXCMD, show.output.on.console = trace, invisible = TRUE)
-    fit$model = selected
-    fit$call = match.call()
-    fit$residuals = scan("OxResiduals.csv", skip = 1, quiet = TRUE)
-    fit$condvars = scan("OxCondVars.csv", skip = 1, quiet = TRUE)
-    fit$coef = matrix(scan("OxParameters.csv", skip = 1, quiet = TRUE), 
-        byrow = TRUE, ncol = 3)
-    
-    # Return Value:
-    class(fit) = "garchOx"
-    invisible(fit)
-}
-
-
-# ------------------------------------------------------------------------------
-
-
-print.garchOx = 
-function(object, digits = max(3, getOption("digits") - 3), ...) 
-{   # A function implemented by Diethelm Wuertz
-    
-    # Description:
-    #   Print method for an object of class "garchOx".
-    
-    # FUNCTION:
-    
-    # Check object:
-    if (!inherits(object, "garchOx")) 
-        stop("method is only for garchOx objects")
-    
-    # Function Call:
-    cat("\nCall:\n")
-    cat(paste(deparse(object$call), sep = "\n", collapse = "\n"), 
-        "\n", sep = "")
-    
-    # Mean Equation:
-    cat("\nMean Equation: ~arma(", object$arma.orders[1], ", ",
-        object$arma.orders[2], ")\n", sep = "")
-    
-    # Conditional Variance Equation:
-    cat("\nConditional Variance Equation: ~", object$model, "(", 
-        object$garch.orders[1], ", ", object$garch.orders[2], ")\n", 
-        sep = "")
-        
-    # Conditional Distribution:
-    cat("\nConditional Distribution: ", object$cond.dist, "\n", 
-    sep = "")
-        
-    # Coefficients:
-    cat("\nCoefficient(s):\n")
-    Value = object$coef[,1]
-    Std.Error = object$coef[,2]
-    t.value = object$coef[,3]
-    coef.names = "Cst(M)"
-    if(object$arfima == 1) coef.names = c(coef.names, "d-arfima")
-    
-    if (object$arma.orders[1] > 0) {
-        for (i in 1:object$arma.orders[1])
-        coef.names = c(coef.names, paste("AR(", as.character(i), ")", 
-            sep=""))}
-    if (object$arma.orders[2] > 0) {
-        for (i in 1:object$arma.orders[2])
-        coef.names = c(coef.names, paste("MA(", as.character(i), ")", 
-            sep=""))}
-    coef.names = c(coef.names, "Cst(V)")
-    if (object$garch.orders[1] > 0) {
-        for (i in 1:object$garch.orders[1])
-        coef.names = c(coef.names, paste("ARCH(", as.character(i), ")", 
-            sep=""))}
-    if (object$garch.orders[2] > 0) {
-        for (i in 1:object$garch.orders[2])
-        coef.names = c(coef.names, paste("GARCH(", as.character(i), ")", 
-            sep=""))}            
-    if (object$cond.dist == "t") coef.names = c(coef.names, "Student(DF)")
-    if (object$cond.dist == "ged") coef.names = c(coef.names, "GED(DF)")
-    if (object$cond.dist == "skewed-t") {
-        coef.names = c(coef.names, "Asymmetry", "Tail")  }
-    if (object$arch.in.mean == 1) {
-        coef.names = c(coef.names, "ARCH-in-mean(var)") }   
-    coef = data.frame(cbind(Value, Std.Error, t.value), row.names=coef.names)
-    print(coef)     
-    cat("\n")
-    
-    # Return Value:
-    invisible(object)
-}
-
-
-# ------------------------------------------------------------------------------
-
-
-plot.garchOx = 
-function(object) 
-{   # A function implemented by Diethelm Wuertz
-
-    # Description:
-    #   Plot method for an object of class "garchOx".
-    
-    # FUNCTION:
-    
-    # Check Object:
-    if (!inherits(object, "garchOx")) 
-        stop("method is only for garchOx objects")
-        
-    # Plot Time Series"
-    plot(object$x, type = "l", main = "Time Series")
-    
-    # Conditional Variances:
-    plot(object$condvars, type = "l", main = "Conditional Variances")
-    
-    # Autocorrelation Functions: 
-    acf(object$x)
-    acf(object$x^2)
-  
-}
-
-
 ################################################################################
 # 5 MISSING DATA MANIPULATIONS
 
